import { BaseClient, BaseClientConfig } from "@commerce-apps/core";
export { PaymentTransactionUpdateRequest, PaymentInstrumentUpdateRequest, OrderPaymentStatusUpdateRequest, OrderConfirmationStatusUpdateRequest, ShippingAddressUpdateRequest, OrderExternalStatusUpdateRequest, OrderShippingStatusUpdateRequest, OrderUpdateRequest, OrderExportStatusUpdateRequest, OrderStatusUpdateRequest, Offset, Limit, SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, } from "./Orders.types";
declare type ClientConfig = BaseClientConfig & {
    baseUriParameters?: {
        "shortCode": string;
        "version": string;
    };
};
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Updates the order.
    */
    patchSitesByIdOrdersById(options: {
        parameters?: {
            organizationId: any;
            orderNo: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the order confirmation status.
    */
    putSitesByIdOrdersByIdConfirmationStatus(options: {
        parameters?: {
            organizationId: any;
            orderNo: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the order export status. Setting the status to EXPORTED will also trigger the finalization of on-order inventory transactions for this order, meaning that all inventory transactions with type on-order are moved into final inventory transactions. This is only relevant when on-order inventory is turned on for the inventory list ordered products are in.
    */
    putSitesByIdOrdersByIdExportStatus(options: {
        parameters?: {
            organizationId: any;
            orderNo: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the order external status.
    */
    putSitesByIdOrdersByIdExternalStatus(options: {
        parameters?: {
            organizationId: any;
            orderNo: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the order payment status.
    */
    putSitesByIdOrdersByIdPaymentStatus(options: {
        parameters?: {
            organizationId: any;
            orderNo: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the order shipping status.
    */
    putSitesByIdOrdersByIdShippingStatus(options: {
        parameters?: {
            organizationId: any;
            orderNo: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the order status. Orders which are in status NEW, OPEN, COMPLETED, or CANCELLED can not be set to status CREATED or FAILED.
    */
    putSitesByIdOrdersByIdStatus(options: {
        parameters?: {
            organizationId: any;
            orderNo: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the payment instrument of an order.
    */
    patchSitesByIdOrdersByIdPaymentInstrumentsById(options: {
        parameters?: {
            organizationId: any;
            orderNo: any;
            paymentInstrumentId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates the transaction of an order payment instrument.
    */
    patchSitesByIdOrdersByIdPaymentInstrumentsByIdTransaction(options: {
        parameters?: {
            organizationId: any;
            orderNo: any;
            paymentInstrumentId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Updates (create or replace) the order shipment address.
    */
    putSitesByIdOrdersByIdShipmentsByIdShippingAddress(options: {
        parameters?: {
            organizationId: any;
            orderNo: any;
            shipmentId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=Orders.d.ts.map