import { BaseClient, BaseClientConfig } from "@commerce-apps/core";
import { PaymentMethodResult, ShippingMethodResult, Basket } from "./ShopperBaskets.types";
export { ErrorResponse, Offset, Limit, PaymentCardSpec, OrderAddress, BasketsResult, PaymentCard, NotesResult, ShippingItem, Discount, Note, CouponItem, PromotionLink, ShippingPromotion, ProductItem, BasketPaymentInstrumentRequest, OrderPaymentInstrument, PaymentBankAccount, BonusDiscountLineItem, PaymentMethodResult, Shipment, CustomerInfo, SimpleLink, PaymentBankAccountRequest, PriceAdjustment, ShippingMethodResult, ProductDetailsLink, OptionItem, ShippingMethod, Basket, OrderPaymentInstrumentRequest, GiftCertificateItem, ProductListLink, Order, OrderPaymentCardRequest, PaymentMethod, Status, ProductListItemReference, SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, } from "./ShopperBaskets.types";
declare type ClientConfig = BaseClientConfig & {
    baseUriParameters?: {
        "shortCode": string;
        "version": string;
    };
};
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Creates a new basket. The created basket is initialized with default values. Data provided in the body document is populated into the created basket. It can be updated with further API calls.

Considered values from the request body are:

- customer information: PUT /baskets/{basketId}/customer

- billing address: PUT /baskets/{basketId}/billing-address

- shipments including shipping address and shipping method: POST /baskets/{basketId}/shipments

- product items: POST /baskets/{basketId}/items

- coupon items: POST /baskets/{basketId}/coupons

- gift certificate items: POST /baskets/{basketId}/gift-certificates

- payment method and card type: POST /baskets/{basketId}/payment-instruments

- custom properties: PATCH /baskets/{basketId}

Related resource means with which resource you can specify the same data after the basket creation.
Identify the basket using the basketId property, which
should be integrated into the path of an update request (for example a POST to
/baskets/{basketId}/items).

A customer must provide a JSON Web Token (JWT), which specifies exactly one customer (it can be a guest or a registered
customer). In this case, the resource creates a basket for this customer.

The number of baskets which can be created per customer is limited. When a
basket is created, it is said to be open. It remains open until either an order is created from it
using a POST to resource /orders, or it is deleted using a DELETE to resource
/baskets/{basketId}. Each customer can have just one open basket.

Custom properties in the form c_&lt;CUSTOM_NAME&gt; are supported. A custom property must correspond to a custom
attribute (&lt;CUSTOM_NAME&gt;) defined for the basket system object, and its value must be valid for that custom
attribute.
    */
    postBaskets(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Removes a basket.
    */
    deleteBasketsById(options?: {
        parameters?: {
            organizationId: any;
            basketId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Gets a basket.
    */
    getBasketsById(options?: {
        parameters?: {
            organizationId: any;
            basketId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Basket>;
    /**
    * Updates a basket. Only the currency of the basket, source code, the custom
properties of the basket, and the shipping items will be considered.
    */
    patchBasketsById(options: {
        parameters?: {
            organizationId: any;
            basketId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Sets the billing address of a basket.
    */
    putBasketsByIdBillingAddress(options: {
        parameters?: {
            organizationId: any;
            basketId: any;
            useAsShipping?: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Adds a coupon to an existing basket.
    */
    postBasketsByIdCoupons(options: {
        parameters?: {
            organizationId: any;
            basketId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Removes a coupon from the basket.
    */
    deleteBasketsByIdCouponsById(options?: {
        parameters?: {
            organizationId: any;
            basketId: any;
            couponItemId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Basket>;
    /**
    * Sets customer information for an existing basket.
    */
    putBasketsByIdCustomer(options: {
        parameters?: {
            organizationId: any;
            basketId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Adds a gift certificate item to an existing basket.
    */
    postBasketsByIdGiftCertificateItems(options: {
        parameters?: {
            organizationId: any;
            basketId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Deletes a gift certificate item from an existing basket.
    */
    deleteBasketsByIdGiftCertificateItemsById(options?: {
        parameters?: {
            organizationId: any;
            basketId: any;
            giftCertificateItemId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Basket>;
    /**
    * Updates a gift certificate item of an existing basket.
    */
    patchBasketsByIdGiftCertificateItemsById(options: {
        parameters?: {
            organizationId: any;
            basketId: any;
            giftCertificateItemId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Adds new items to a basket. The added items are associated with the
specified shipment. If no shipment id is specified, the added items are associated with the default shipment.
Considered values from the request body, for each item are:

- productId: a valid product ID. This is the ID of the product to be added to the basket. If the
product is already in the basket, the API either increments the quantity of the existing product line item or
creates a new product line item, based on the site preference &#x27;Add Product Behavior&#x27;. For option products and
product bundles containing variation masters, the API creates a new product line item regardless of the site
preference.
- shipmentId: a valid shipment ID (optional). This is the ID of the shipment in which the product item
is created.
- quantity: a number between 0.01 and 999. This is the quantity of the product to order.
- inventoryId: a valid inventory ID (optional). This is the ID of the inventory from which the item is
allocated.
- bonusDiscountLineItemId: a valid bonus discount line item ID (optional). This is the ID of the
bonus discount line item for which the added product is a selected bonus product.
- optionItems/optionValueId: a valid option value ID. This is an option value for an option item of
an option product.  This is only possible if the product item is an option
product. To set option values, you must specify a collection of option items in the optionItems
property. These option items must contain optionId and optionValueId. Also,
the values you specify must be valid for the option product that this product item represents. Otherwise, the
server throws an InvalidProductOptionItemException or an
InvalidProductOptionValueItemException.
- custom properties in the form c_&lt;CUSTOM_NAME&gt;: the custom property must correspond to a custom
attribute (&lt;CUSTOM_NAME&gt;) defined for ProductLineItem. The value of this property must be valid for the
type of custom attribute defined for ProductLineItem.
    */
    postBasketsByIdItems(options: {
        parameters?: {
            organizationId: any;
            basketId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Removes a product item from the basket.
    */
    deleteBasketsByIdItemsById(options?: {
        parameters?: {
            organizationId: any;
            basketId: any;
            itemId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Basket>;
    /**
    * Updates an item in a basket. The
following values in the request body are considered by the server:

- productId: a valid product ID. The purpose of this
value is to exchange a variation of a variation product.
- shipmentId: a valid shipment ID. The purpose of
this value is to move a product item to another shipment.
- quantity: a number between 0 and 999. The purpose of
this value is to change quantity of the product item. If quantity is 0,
the product item is removed.
- optionItems/optionValueId: a valid option value
ID. The purpose of this value is to exchange an option value for an
option item of an option product.
This is only possible if the product item is an option product. To change
option values a collection of option items to be changed need to be
provided in property optionItems. Those
optionItems need to contain optionId
and optionValueId. The provided values must be valid
for the option product that this product item represents. Otherwise
InvalidProductOptionItemException or
InvalidProductOptionValueItemException will be thrown.
custom properties c_&lt;CUSTOM_NAME&gt;: a
value corresponding to the type defined for custom attribute
&lt;CUSTOM_NAME&gt; of ProductLineItem. The purpose of this value is to
add or change the value of a custom attribute defined for
ProductLineItem.
    */
    patchBasketsByIdItemsById(options: {
        parameters?: {
            organizationId: any;
            basketId: any;
            itemId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Adds a payment instrument to a basket.
    */
    postBasketsByIdPaymentInstruments(options: {
        parameters?: {
            organizationId: any;
            basketId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Removes a payment instrument of a basket.
    */
    deleteBasketsByIdPaymentInstrumentsById(options?: {
        parameters?: {
            organizationId: any;
            basketId: any;
            paymentInstrumentId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Basket>;
    /**
    * Updates a payment instrument of a basket.
    */
    patchBasketsByIdPaymentInstrumentsById(options: {
        parameters?: {
            organizationId: any;
            basketId: any;
            paymentInstrumentId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Gets applicable payment methods for an existing basket considering the open payment amount only.
    */
    getBasketsByIdPaymentMethods(options?: {
        parameters?: {
            organizationId: any;
            basketId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | PaymentMethodResult>;
    /**
    * Creates a new shipment for a basket.

The created shipment is initialized with values provided in the body
document and can be updated with further data API calls. Considered from
the body are the following properties if specified:

- the ID
- the shipping address
- the shipping method
- gift boolean flag
- gift message
- custom properties
    */
    postBasketsByIdShipments(options: {
        parameters?: {
            organizationId: any;
            basketId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Removes a specified shipment and all associated product, gift certificate,
shipping, and price adjustment line items from a basket.
It is not allowed to remove the default shipment.
    */
    deleteBasketsByIdShipmentsById(options?: {
        parameters?: {
            organizationId: any;
            basketId: any;
            shipmentId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Basket>;
    /**
    * Updates a shipment for a basket.

The shipment is initialized with values provided in the body
document and can be updated with further data API calls. Considered from
the body are the following properties if specified:
- the ID
- the shipping address
- the shipping method
- gift boolean flag
- gift message
- custom properties
    */
    patchBasketsByIdShipmentsById(options: {
        parameters?: {
            organizationId: any;
            basketId: any;
            shipmentId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Sets a shipping address of a specific shipment of a basket.
    */
    putBasketsByIdShipmentsByIdShippingAddress(options: {
        parameters?: {
            organizationId: any;
            basketId: any;
            shipmentId: any;
            useAsBilling?: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Sets a shipping method to a specific shipment of a basket.
    */
    putBasketsByIdShipmentsByIdShippingMethod(options: {
        parameters?: {
            organizationId: any;
            basketId: any;
            shipmentId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Basket>;
    /**
    * Gets the applicable shipping methods for a certain shipment of a basket.
    */
    getBasketsByIdShipmentsByIdShippingMethods(options?: {
        parameters?: {
            organizationId: any;
            basketId: any;
            shipmentId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | ShippingMethodResult>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=ShopperBaskets.d.ts.map