"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
class Client extends core_1.BaseClient {
    constructor(config) {
        super(config);
        if (!!!config.baseUri) {
            this.clientConfig.baseUri = "https://{shortCode}.api.commercecloud.salesforce.com/checkout/shopper-orders/{version}";
        }
    }
    /**
    * Submits an order based on a prepared basket. The only considered value from the request body is basketId.
    */
    postOrders(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/orders",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Gets information for an order.
    */
    getOrdersById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "orderNo": parameters["orderNo"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/orders/{orderNo}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
    /**
    * Adds a payment instrument to an order. It is possible to either supply the full payment information, or only a
customer payment instrument ID and amount. In case the customer payment instrument ID was set, all the other
properties (except amount) are ignored and the payment data is resolved from the stored customer payment
information.

Details:

The payment instrument is added with the provided details, or the details from the customer payment
instrument. The payment method must be applicable for the order see GET
/baskets/{basketId}/payment-methods, if the payment method is &#x27;CREDIT_CARD&#x27; a
paymentCard must be specified in the request.
    */
    postOrdersByIdPaymentInstruments(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "orderNo": parameters["orderNo"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/orders/{orderNo}/payment-instruments",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Removes a payment instrument of an order.
    */
    deleteOrdersByIdPaymentInstrumentsById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "orderNo": parameters["orderNo"],
            "paymentInstrumentId": parameters["paymentInstrumentId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/organizations/{organizationId}/orders/{orderNo}/payment-instruments/{paymentInstrumentId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
    /**
    * Updates a payment instrument of an order.

Details:

The payment instrument is updated with the provided details. The payment method must be applicable for the
order see GET /baskets/{basketId}/payment-methods, if the payment method is &#x27;CREDIT_CARD&#x27; a
paymentCard must be specified in the request.
    */
    patchOrdersByIdPaymentInstrumentsById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "orderNo": parameters["orderNo"],
            "paymentInstrumentId": parameters["paymentInstrumentId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/organizations/{organizationId}/orders/{orderNo}/payment-instruments/{paymentInstrumentId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Gets the applicable payment methods for an existing order considering the open payment amount only.
    */
    getOrdersByIdPaymentMethods(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "orderNo": parameters["orderNo"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/orders/{orderNo}/payment-methods",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=ShopperOrders.js.map