import { BaseClient, BaseClientConfig } from "@commerce-apps/core";
import { CustomerAddress, CustomerGroupSearchResult, CustomerList, CustomerGroupMembers, CustomerGroup, CustomerGroupMemberSearchResult, CustomerAddressResult, Customer, CustomerGroupMember, CustomerSearchResult } from "./Customers.types";
export { SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, Error, CustomerAddress, CustomerGroupSearchResult, CustomerList, CustomerSearchHit, CustomerGroupMembers, Rule, CustomerGroup, CustomerGroupMemberSearchResult, CustomerAddressResult, Customer, CustomerGroupMember, Credentials, CustomerSearchResult, } from "./Customers.types";
declare type ClientConfig = BaseClientConfig & {
    baseUriParameters?: {
        "shortCode": string;
    };
};
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Action to search for customers in a customer list.
The query attribute specifies a complex query that can be used to narrow down the search. These are the list
of searchable attributes:
  
customer_no - String
first_name - String
second_name - String
last_name - String
suffix - String
salutation - String
title - String
fax - String
phone_home - String
phone_business - String
phone_mobile - String
email - String
gender - Integer
company_name - String
credentials.login - String
credentials.enabled - boolean
  
    */
    searchCustomerInCustomerList(options: {
        parameters?: {
            organizationId: any;
            customerListId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerSearchResult>;
    /**
    * Action to read an existing customer list.
    */
    getCustomerList(options?: {
        parameters?: {
            organizationId: any;
            listId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerList>;
    /**
    * Action to create a new customer. The customer is created using the specified credentials and customer
information. This action verifies the following:

Login acceptance criteria and uniqueness.
Mandatory customer properties.

If the action fails to create the customer, it returns a 400 fault with an appropriate message.
    */
    createCustomerList(options: {
        parameters?: {
            organizationId: any;
            listId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Customer>;
    /**
    * Deletes the customer, including all related information like the customer addresses.
    */
    deleteCustomerFromCustomerList(options?: {
        parameters?: {
            organizationId: any;
            listId: any;
            customerNo: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Action to get customer information.
    */
    getCustomerFromCustomerList(options?: {
        parameters?: {
            organizationId: any;
            listId: any;
            customerNo: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Customer>;
    /**
    * Updates the customer with the specified information. The customer number is allowed to be updated but results in a
CustomerNumberAlreadyInUseException if there is another customer with the same customer number existing.
    */
    updateCustomerInCustomerList(options: {
        parameters?: {
            organizationId: any;
            listId: any;
            customerNo: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Customer>;
    /**
    * Action to create a new customer. The customer is created using the specified customer number, credentials, and
customer information. This action verifies the following:

Login acceptance criteria and uniqueness.
Mandatory customer properties.

If the action fails to create the customer, it returns a 400 fault with an appropriate message.
    */
    createCustomerInCustomerList(options: {
        parameters?: {
            organizationId: any;
            listId: any;
            customerNo: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Customer>;
    /**
    * Action that returns a pageable list of all customer addresses. The
default page size is 10 customer addresses.
    */
    getAddressesForCustomerFromCustomerList(options?: {
        parameters?: {
            organizationId: any;
            listId: any;
            customerNo: any;
            offset?: any;
            limit: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerAddressResult>;
    /**
    * The action creates a new customer address with the given address
information.
    */
    createAdressForCustomerInCustomerList(options: {
        parameters?: {
            organizationId: any;
            listId: any;
            customerNo: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerAddress>;
    /**
    * Action that returns a single customer address from a customer list.
    */
    getAddressForCustomerFromCustomerList(options?: {
        parameters?: {
            organizationId: any;
            listId: any;
            customerNo: any;
            addressId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerAddress>;
    /**
    * Action which deletes a customer address.
    */
    removeAddressForCustomerInCustomerList(options?: {
        parameters?: {
            organizationId: any;
            listId: any;
            customerNo: any;
            addressId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Action which updates an address of a customer with the given address information.
    */
    updateAddressForCustomerInCustomerList(options: {
        parameters?: {
            organizationId: any;
            listId: any;
            customerNo: any;
            addressId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerAddress>;
    /**
    * Action to get site customer groups.
    */
    getAllCustomerGroupsFromSite(options?: {
        parameters?: {
            organizationId: any;
            siteId: any;
            offset?: any;
            limit: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerGroup>;
    /**
    * Action to get customer group information.
    */
    getCustomerGroupFromSite(options?: {
        parameters?: {
            organizationId: any;
            siteId: any;
            customerGroupId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerGroup>;
    /**
    * Triggers customer group deletion by ID. The deletion happens via asynchronous batch process
which is the reason the deletion itself is not necessarily finished after the call to this resource is returned. The customer group that is in deletion is provided in the response.
    */
    deleteCustomerGroupFromSite(options?: {
        parameters?: {
            organizationId: any;
            siteId: any;
            customerGroupId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerGroup>;
    /**
    * Updates the customer group with the specified information.
    */
    updateCustomerGroupInSite(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
            customerGroupId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerGroup>;
    /**
    * Creates a customer group using the information provided.
    */
    createCustomerGroupInSite(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
            customerGroupId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerGroup>;
    /**
    * Searches for customer group members. For dynamic customer groups, and the system groups &quot;Everyone&quot; and &quot;Unregistered&quot;, no result is returned (Status Code: 204 - No Content).

The query attribute specifies a complex query that can be used to narrow down the search. Attributes are grouped
into different buckets. These are the searchable attributes with their corresponding buckets:

Main:

      login - String
      active - Boolean

Customer Profile:

      customer_no - String
      first_name - String
      last_name - String
      email - String
      zip - String


Only attributes in the same bucket can be joined using a disjunction (OR).
For instance, when joining login and customer_no above, only a conjunction is allowed (AND), whereas customer_no
and email can be joined using a disjunction because they are in the same bucket.  If an attribute
is used in a disjunction (OR) that violates this rule, an exception is thrown.

The output of the query can also be sorted. These are the list of sortable attributes:

customer_no - String
login - String


If the Business Manager customer search is configured to use the new Search Service, the following differences apply:

    all attributes can be used for sorting (except for &#x27;active&#x27;).
    searching for &#x27;zip&#x27; will only search in the customers default address.
    logical operators can be used without limits (but may result in degraded performance, depending on how they are combined).
    new assignments might not be found immediately via the search service, and removed assignments
    might also not be in effect immediately (there is a slight delay in updating the index).
    */
    searchMembersInCustomerGroupAssignedToSite(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
            customerGroupId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerGroupMemberSearchResult>;
    /**
    * Action to get all the customer group members with no filtering. For dynamic customer groups, and the system groups &quot;Everyone&quot; and &quot;Unregistered&quot;, no result is returned (Status Code: 204 - No Content).
    */
    getMembersFromCustomerGroupAssignedToSite(options?: {
        parameters?: {
            organizationId: any;
            siteId: any;
            customerGroupId: any;
            offset?: any;
            limit: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerGroupMembers>;
    /**
    * Action to get customer group member information.
    */
    getMemberFromCustomerGroupAssignedToSite(options?: {
        parameters?: {
            organizationId: any;
            siteId: any;
            customerGroupId: any;
            customerNo: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerGroupMember>;
    /**
    * Action to remove a customer from a static customer group.
    */
    deleteMemberFromCustomerGroupAssignedToSite(options?: {
        parameters?: {
            organizationId: any;
            siteId: any;
            customerGroupId: any;
            customerNo: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Action to add customer to static customer group.
    */
    addMemberToCustomerGroupAssignedToSite(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
            customerGroupId: any;
            customerNo: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerGroupMember>;
    /**
    * Searches for customer groups.

The query attribute specifies a complex query that can be used to narrow down the search. These are the list
of searchable attributes:

id - String
description - String
type - String Enum value[system, dynamic, static]


The output of the query can also be sorted. These are the list of sortable attributes:

id - String
description - String
    */
    searchCustomerGroupInSite(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerGroupSearchResult>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=Customers.d.ts.map