"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
class Client extends core_1.BaseClient {
    constructor(config) {
        super(config);
        if (!!!config.baseUri) {
            this.clientConfig.baseUri = "http://{shortCode}.api.commercecloud.salesforce.com/customer/customers/v1";
        }
        this.authSchemes["OAuth2_0"] = new core_1.AuthSchemes["OAuth2_0"]();
    }
    /**
    * Action to search for customers in a customer list.
The query attribute specifies a complex query that can be used to narrow down the search. These are the list
of searchable attributes:
  
customer_no - String
first_name - String
second_name - String
last_name - String
suffix - String
salutation - String
title - String
fax - String
phone_home - String
phone_business - String
phone_mobile - String
email - String
gender - Integer
company_name - String
credentials.login - String
credentials.enabled - boolean
  
    */
    searchCustomerInCustomerList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerListId": parameters["customerListId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/customer-lists/{customerListId}/customer-search",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to read an existing customer list.
    */
    getCustomerList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "listId": parameters["listId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customer-lists/{listId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to create a new customer. The customer is created using the specified credentials and customer
information. This action verifies the following:

Login acceptance criteria and uniqueness.
Mandatory customer properties.

If the action fails to create the customer, it returns a 400 fault with an appropriate message.
    */
    createCustomerList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "listId": parameters["listId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/customer-lists/{listId}/customers",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Deletes the customer, including all related information like the customer addresses.
    */
    deleteCustomerFromCustomerList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "listId": parameters["listId"],
            "customerNo": parameters["customerNo"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/organizations/{organizationId}/customer-lists/{listId}/customers/{customerNo}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to get customer information.
    */
    getCustomerFromCustomerList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "listId": parameters["listId"],
            "customerNo": parameters["customerNo"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customer-lists/{listId}/customers/{customerNo}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Updates the customer with the specified information. The customer number is allowed to be updated but results in a
CustomerNumberAlreadyInUseException if there is another customer with the same customer number existing.
    */
    updateCustomerInCustomerList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "listId": parameters["listId"],
            "customerNo": parameters["customerNo"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/organizations/{organizationId}/customer-lists/{listId}/customers/{customerNo}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to create a new customer. The customer is created using the specified customer number, credentials, and
customer information. This action verifies the following:

Login acceptance criteria and uniqueness.
Mandatory customer properties.

If the action fails to create the customer, it returns a 400 fault with an appropriate message.
    */
    createCustomerInCustomerList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "listId": parameters["listId"],
            "customerNo": parameters["customerNo"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/organizations/{organizationId}/customer-lists/{listId}/customers/{customerNo}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action that returns a pageable list of all customer addresses. The
default page size is 10 customer addresses.
    */
    getAddressesForCustomerFromCustomerList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "listId": parameters["listId"],
            "customerNo": parameters["customerNo"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customer-lists/{listId}/customers/{customerNo}/addresses",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * The action creates a new customer address with the given address
information.
    */
    createAdressForCustomerInCustomerList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "listId": parameters["listId"],
            "customerNo": parameters["customerNo"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/customer-lists/{listId}/customers/{customerNo}/addresses",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action that returns a single customer address from a customer list.
    */
    getAddressForCustomerFromCustomerList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "listId": parameters["listId"],
            "customerNo": parameters["customerNo"],
            "addressId": parameters["addressId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customer-lists/{listId}/customers/{customerNo}/addresses/{addressId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action which deletes a customer address.
    */
    removeAddressForCustomerInCustomerList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "listId": parameters["listId"],
            "customerNo": parameters["customerNo"],
            "addressId": parameters["addressId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/organizations/{organizationId}/customer-lists/{listId}/customers/{customerNo}/addresses/{addressId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action which updates an address of a customer with the given address information.
    */
    updateAddressForCustomerInCustomerList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "listId": parameters["listId"],
            "customerNo": parameters["customerNo"],
            "addressId": parameters["addressId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/organizations/{organizationId}/customer-lists/{listId}/customers/{customerNo}/addresses/{addressId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to get site customer groups.
    */
    getAllCustomerGroupsFromSite(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/sites/{siteId}/customer-groups",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to get customer group information.
    */
    getCustomerGroupFromSite(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "siteId": parameters["siteId"],
            "customerGroupId": parameters["customerGroupId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/sites/{siteId}/customer-groups/{customerGroupId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Triggers customer group deletion by ID. The deletion happens via asynchronous batch process
which is the reason the deletion itself is not necessarily finished after the call to this resource is returned. The customer group that is in deletion is provided in the response.
    */
    deleteCustomerGroupFromSite(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "siteId": parameters["siteId"],
            "customerGroupId": parameters["customerGroupId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/organizations/{organizationId}/sites/{siteId}/customer-groups/{customerGroupId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Updates the customer group with the specified information.
    */
    updateCustomerGroupInSite(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "siteId": parameters["siteId"],
            "customerGroupId": parameters["customerGroupId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/organizations/{organizationId}/sites/{siteId}/customer-groups/{customerGroupId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Creates a customer group using the information provided.
    */
    createCustomerGroupInSite(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "siteId": parameters["siteId"],
            "customerGroupId": parameters["customerGroupId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/organizations/{organizationId}/sites/{siteId}/customer-groups/{customerGroupId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Searches for customer group members. For dynamic customer groups, and the system groups &quot;Everyone&quot; and &quot;Unregistered&quot;, no result is returned (Status Code: 204 - No Content).

The query attribute specifies a complex query that can be used to narrow down the search. Attributes are grouped
into different buckets. These are the searchable attributes with their corresponding buckets:

Main:

      login - String
      active - Boolean

Customer Profile:

      customer_no - String
      first_name - String
      last_name - String
      email - String
      zip - String


Only attributes in the same bucket can be joined using a disjunction (OR).
For instance, when joining login and customer_no above, only a conjunction is allowed (AND), whereas customer_no
and email can be joined using a disjunction because they are in the same bucket.  If an attribute
is used in a disjunction (OR) that violates this rule, an exception is thrown.

The output of the query can also be sorted. These are the list of sortable attributes:

customer_no - String
login - String


If the Business Manager customer search is configured to use the new Search Service, the following differences apply:

    all attributes can be used for sorting (except for &#x27;active&#x27;).
    searching for &#x27;zip&#x27; will only search in the customers default address.
    logical operators can be used without limits (but may result in degraded performance, depending on how they are combined).
    new assignments might not be found immediately via the search service, and removed assignments
    might also not be in effect immediately (there is a slight delay in updating the index).
    */
    searchMembersInCustomerGroupAssignedToSite(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "siteId": parameters["siteId"],
            "customerGroupId": parameters["customerGroupId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/sites/{siteId}/customer-groups/{customerGroupId}/member-search",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to get all the customer group members with no filtering. For dynamic customer groups, and the system groups &quot;Everyone&quot; and &quot;Unregistered&quot;, no result is returned (Status Code: 204 - No Content).
    */
    getMembersFromCustomerGroupAssignedToSite(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "siteId": parameters["siteId"],
            "customerGroupId": parameters["customerGroupId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/sites/{siteId}/customer-groups/{customerGroupId}/members",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to get customer group member information.
    */
    getMemberFromCustomerGroupAssignedToSite(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "siteId": parameters["siteId"],
            "customerGroupId": parameters["customerGroupId"],
            "customerNo": parameters["customerNo"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/sites/{siteId}/customer-groups/{customerGroupId}/members/{customerNo}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to remove a customer from a static customer group.
    */
    deleteMemberFromCustomerGroupAssignedToSite(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "siteId": parameters["siteId"],
            "customerGroupId": parameters["customerGroupId"],
            "customerNo": parameters["customerNo"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/organizations/{organizationId}/sites/{siteId}/customer-groups/{customerGroupId}/members/{customerNo}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to add customer to static customer group.
    */
    addMemberToCustomerGroupAssignedToSite(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "siteId": parameters["siteId"],
            "customerGroupId": parameters["customerGroupId"],
            "customerNo": parameters["customerNo"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/organizations/{organizationId}/sites/{siteId}/customer-groups/{customerGroupId}/members/{customerNo}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Searches for customer groups.

The query attribute specifies a complex query that can be used to narrow down the search. These are the list
of searchable attributes:

id - String
description - String
type - String Enum value[system, dynamic, static]


The output of the query can also be sorted. These are the list of sortable attributes:

id - String
description - String
    */
    searchCustomerGroupInSite(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/sites/{siteId}/customer-group-search",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.OAuth2_0
        });
    }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=Customers.js.map