import { BaseClient, BaseClientConfig } from "@commerce-apps/core";
import { CustomerAddress, CustomerProductListResult, PublicProductListResult, BasketsResult, ResetPasswordToken, CustomerPaymentInstrumentResult, CustomerProductListItemResult, CustomerPaymentInstrument, PublicProductListItem, CustomerProductList, PublicProductListItemResult, CustomerAddressResult, Customer, PublicProductList, CustomerOrderResult, CustomerProductListItem } from "./ShopperCustomers.types";
export { Error, SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, CustomerAddress, CustomerProductListResult, CustomerProductListItemPurchase, OptionValue, Master, OrderAddress, PublicProductListResult, BasketsResult, TrustedSystemAuthRequest, ResetPasswordRequest, PaymentCard, ShippingItem, Discount, ResetPasswordToken, CouponItem, CustomerPaymentInstrumentResult, ShippingPromotion, VariationAttribute, ProductListShippingAddress, ProductItem, CustomerProductListRegistrant, PublicProductListInfo, CustomerPaymentCardRequest, RecommendationType, OrderPaymentInstrument, CustomerProductListItemResult, ProductType, PaymentBankAccount, Recommendation, Variant, BonusDiscountLineItem, CustomerPaymentInstrument, Shipment, CustomerInfo, VariationGroup, SimpleLink, PaymentBankAccountRequest, PriceAdjustment, PublicProductListItem, ProductDetailsLink, ProductLink, OptionItem, ShippingMethod, ProductListEvent, PasswordChangeRequest, AuthRequest, Inventory, CustomerProductList, Basket, PublicProductListItemResult, CustomerPaymentInstrumentRequest, ImageGroup, CustomerAddressResult, CustomerProductListItemPurchaseResult, Customer, PublicProductList, Option, CustomerOrderResult, GiftCertificateItem, CustomerAddressInfo, ResetPasswordTokenRequest, ProductListLink, ProductListRegistrant, Order, Product, Image, VariationAttributeValue, ProductPromotion, BundledProduct, Status, CustomerProductListItem, ProductListItemReference, } from "./ShopperCustomers.types";
declare type ClientConfig = BaseClientConfig & {
    baseUriParameters?: {
        "shortCode": string;
    };
};
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Registers a new customer. The mandatory data are the credentials, profile last name, and email. This requires a JSON Web Token (JWT) which needs to be obtained using the POST /customers/auth API with type &quot;guest&quot;.
    */
    registerCustomer(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Customer>;
    /**
    * Invalidates the JSON Web Token (JWT) provided in the header.
    */
    invalidateCustomerAuth(options?: {
        parameters?: {
            organizationId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Obtains a new JSON Web Token (JWT)for a guest or registered
customer. Tokens are returned as an HTTP Authorization:Bearer response
header entry. These kinds of request are supported, as specified by the
type:

Type guest - creates a guest (non-authenticated) customer
and returns a token for the customer.
Type credentials - authenticates credentials passed in the
HTTP Authorization:Basic request header, returning a token for a
successfully authenticated customer, otherwise it throws an
AuthenticationFailedException.
Type session - authenticates the customer (anonymous or registered)
based on the dwsid and dwsecuretoken cookies. It returns a token for a
successfully authenticated customer, otherwise it throws an
AuthenticationFailedException.
Type refresh - examines the token passed in the HTTP
Authorization:Bearer request header and when valid returns a new token
with an updated expiry time.


For a request of type credentials:

Updates profile attributes for the customer (for example,
&quot;last-visited&quot;).
Handles the maximum number of failed login attempts.

For a request of type session:

The session and corresponding dwsecuretoken must be active and valid. An expired session can&#x27;t be
used. The dwsecuretoken cookie must have been used for at least one
previous HTTPS request with the same dwsid cookie.
Does not touch profile attributes for the registered customer (for example,
&quot;last-visited&quot;), since this is not a real login.
Returns different tokens for multiple requests with the same session ID. Means, there should be
only one call per session.


About JWT The token contains 3 sections:

The header section (specifies token type and algorithm used),
the payload section (contains customer information, client ID,
issue, and expiration time),
finally the signature section records the token signature.

A token is created and returned to the client whenever a registered
customer logs in (type &quot;credentials&quot;) or a guest customer requests it (type
&quot;guest&quot;). The token is returned in the response header as
Authorization: Bearer --token--

The client has to include the token in the request header as
Authorization: Bearer --token--
in any follow-up request. The server declines any follow-up requests
without a token or which cannot be verified based on the token signature
or expiration time. A token nearing its expiration time should be
exchanged for a new one (type &quot;refresh&quot;).

See &quot;API Usage &gt; JWT&quot; for more details on using JWT as an authentication
mechanism.
    */
    authorizeCustomer(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Customer>;
    /**
    * Obtain the JSON Web Token (JWT) for registered customers whose credentials are stored using a third party system. Accepts loginId and clientId, returns a customer object in the response body and the JWT generated against the clientId in the response header.
    */
    authorizeTrustedSystem(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Customer>;
    /**
    * Reset customer password.
    */
    postResetPassword(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Create reset password token.
    */
    postResetPasswordToken(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ResetPasswordToken>;
    /**
    * Gets a customer.
    */
    getCustomer(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            siteId: any;
            expand?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Customer>;
    /**
    * Updates a customer.
    */
    updateCustomer(options: {
        parameters?: {
            organizationId: any;
            customerId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Customer>;
    /**
    * Returns a sorted pageable list of all customer addresses in the address book. The default page size is 10
customer addresses. The addresses are sorted so that the preferred address is always sorted first, with the remaining
addresses sorted alphabetically by ID.

When the customer cannot be found, NotFoundException
is thrown in a case of an agent, or an empty result list is returned in a case of JWT.
    */
    getCustomerAddresses(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            siteId: any;
            offset?: any;
            limit: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerAddressResult>;
    /**
    * Creates a new address with the given name for the given customer.
    */
    createCustomerAddress(options: {
        parameters?: {
            organizationId: any;
            customerId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerAddress>;
    /**
    * Retrieves a customer&#x27;s address by address name.
    */
    getCustomerAddress(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            addressName: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerAddress>;
    /**
    * Deletes a customer&#x27;s address by address name.
    */
    removeCustomerAddress(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            addressName: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Updates a customer&#x27;s address by address name.
    */
    updateCustomerAddress(options: {
        parameters?: {
            organizationId: any;
            customerId: any;
            addressName: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerAddress>;
    /**
    * Gets the baskets of a customer.
    */
    getCustomerBaskets(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | BasketsResult>;
    /**
    * Returns a pageable list of all customer&#x27;s orders. The default page size is 10.
    */
    getCustomerOrders(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            siteId: any;
            crossSites?: any;
            from?: any;
            until?: any;
            status?: any;
            offset?: any;
            limit: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerOrderResult>;
    /**
    * Updates the customer&#x27;s password.
    */
    updateCustomerPassword(options: {
        parameters?: {
            organizationId: any;
            customerId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Gets customer payment instruments for an customer. Can be limited to a specific payment
method by providing the query parameter paymentMethodId.

When the customer cannot be found NotFoundException
is thrown in a case of an agent, but an empty result list is returned in a case of JWT.
    */
    getCustomerPaymentInstruments(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerPaymentInstrumentResult>;
    /**
    * Adds a payment instrument to the customer information.
    */
    createCustomerPaymentInstrument(options: {
        parameters?: {
            organizationId: any;
            customerId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerPaymentInstrument>;
    /**
    * Deletes a customer&#x27;s payment instrument.
    */
    deleteCustomerPaymentInstrument(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            paymentInstrumentId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Retrieves a customer&#x27;s payment instrument by its ID.
    */
    getCustomerPaymentInstrument(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            paymentInstrumentId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerPaymentInstrument>;
    /**
    * Returns all customer product lists.
    */
    getCustomerProductLists(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            siteId: any;
            expand?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerProductListResult>;
    /**
    * Creates a customer product list.
    */
    createCustomerProductList(options: {
        parameters?: {
            organizationId: any;
            customerId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerProductList>;
    /**
    * Deletes a customer product list.
    */
    deleteCustomerProductList(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            listId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Returns a customer product list of the given customer.
    */
    getCustomerProductList(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            listId: any;
            siteId: any;
            expand?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerProductList>;
    /**
    * Changes a product list. Changeable properties are the name, description, and if the list is public.
    */
    updateCustomerProductList(options: {
        parameters?: {
            organizationId: any;
            customerId: any;
            listId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerProductList>;
    /**
    * Returns a pageable list of all items of a customer&#x27;s product list. The default page size is 10.
    */
    getCustomerProductListItems(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            listId: any;
            siteId: any;
            expand?: any;
            offset?: any;
            limit: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerProductListItemResult>;
    /**
    * Adds an item to the customer&#x27;s product list. Considered values from the request body are:

type: A valid type, mandatory. This is the type of the item to be added to the customer&#x27;s product.
list.
priority: This is the priority of the item to be added to the customer&#x27;s product list.
public: This is the flag whether the item to be added to the customer&#x27;s product list is public.
product_id: A valid product ID, used for product item type only. This is the ID (SKU)
of the product related to the item to be added to the customer&#x27;s product list. It is mandatory for
product item type, and it must be a valid product id, otherwise
ProductListProductIdMissingException or ProductListProductNotFoundException
will be thrown.
quantity: Used for product item type only. This is the quantity of the item to be
added to the customer&#x27;s product list.
custom properties in the form c_&lt;CUSTOM_NAME&gt;: The custom property must correspond to a custom
attribute (&lt;CUSTOM_NAME&gt;) defined for ProductListItem. The value of this property must be valid for the
type of custom attribute defined for ProductListItem.
    */
    createCustomerProductListItem(options: {
        parameters?: {
            organizationId: any;
            customerId: any;
            listId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerProductListItem>;
    /**
    * Removes an item from a customer product list.
    */
    deleteCustomerProductListItem(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            listId: any;
            itemId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Returns an item of a customer product list.
    */
    getCustomerProductListItem(options?: {
        parameters?: {
            organizationId: any;
            customerId: any;
            listId: any;
            itemId: any;
            siteId: any;
            expand?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CustomerProductListItem>;
    /**
    * Updates an item of a customer&#x27;s product list.
Considered values from the request body are:

priority: This is the priority of the customer&#x27;s product list item.
public: This is the flag whether the customer&#x27;s product list item is public.
quantity: This is the quantity of
the customer&#x27;s product list item. Used for product item type only.
custom properties in the form c_&lt;CUSTOM_NAME&gt;: The custom property
must correspond to a custom attribute (&lt;CUSTOM_NAME&gt;) defined for ProductListItem.
The value of this property must be valid for the type of custom attribute defined for ProductListItem.
    */
    updateCustomerProductListItem(options: {
        parameters?: {
            organizationId: any;
            customerId: any;
            listId: any;
            itemId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CustomerProductListItem>;
    /**
    * Retrieves all public product lists as defined by the given search term (for example, email, first name, or last name).
    */
    getPublicProductListsBySearchTerm(options?: {
        parameters?: {
            organizationId: any;
            siteId: any;
            email?: any;
            firstName?: any;
            lastName?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | PublicProductListResult>;
    /**
    * Retrieves a public product list by ID.
    */
    getPublicProductList(options?: {
        parameters?: {
            organizationId: any;
            listId: any;
            siteId: any;
            expand?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | PublicProductList>;
    /**
    * Retrieves the items of a public product list.
    */
    getProductListItems(options?: {
        parameters?: {
            organizationId: any;
            listId: any;
            siteId: any;
            expand?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | PublicProductListItemResult>;
    /**
    * Retrieves an item from a public product list.
    */
    getProductListItem(options?: {
        parameters?: {
            organizationId: any;
            listId: any;
            itemId: any;
            siteId: any;
            expand?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | PublicProductListItem>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=ShopperCustomers.d.ts.map