"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
class Client extends core_1.BaseClient {
    constructor(config) {
        super(config);
        if (!!!config.baseUri) {
            this.clientConfig.baseUri = "https://{shortCode}.api.commercecloud.salesforce.com/customer/shopper-customers/v1";
        }
        this.authSchemes["OAuth2_0"] = new core_1.AuthSchemes["OAuth2_0"]();
        this.authSchemes["ShopperJWT"] = new core_1.AuthSchemes["ShopperJWT"]();
        this.authSchemes["clientId"] = new core_1.AuthSchemes["clientId"]();
    }
    /**
    * Registers a new customer. The mandatory data are the credentials, profile last name, and email. This requires a JSON Web Token (JWT) which needs to be obtained using the POST /customers/auth API with type &quot;guest&quot;.
    */
    registerCustomer(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/customers",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Invalidates the JSON Web Token (JWT) provided in the header.
    */
    invalidateCustomerAuth(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/organizations/{organizationId}/customers/auth",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Obtains a new JSON Web Token (JWT)for a guest or registered
customer. Tokens are returned as an HTTP Authorization:Bearer response
header entry. These kinds of request are supported, as specified by the
type:

Type guest - creates a guest (non-authenticated) customer
and returns a token for the customer.
Type credentials - authenticates credentials passed in the
HTTP Authorization:Basic request header, returning a token for a
successfully authenticated customer, otherwise it throws an
AuthenticationFailedException.
Type session - authenticates the customer (anonymous or registered)
based on the dwsid and dwsecuretoken cookies. It returns a token for a
successfully authenticated customer, otherwise it throws an
AuthenticationFailedException.
Type refresh - examines the token passed in the HTTP
Authorization:Bearer request header and when valid returns a new token
with an updated expiry time.


For a request of type credentials:

Updates profile attributes for the customer (for example,
&quot;last-visited&quot;).
Handles the maximum number of failed login attempts.

For a request of type session:

The session and corresponding dwsecuretoken must be active and valid. An expired session can&#x27;t be
used. The dwsecuretoken cookie must have been used for at least one
previous HTTPS request with the same dwsid cookie.
Does not touch profile attributes for the registered customer (for example,
&quot;last-visited&quot;), since this is not a real login.
Returns different tokens for multiple requests with the same session ID. Means, there should be
only one call per session.


About JWT The token contains 3 sections:

The header section (specifies token type and algorithm used),
the payload section (contains customer information, client ID,
issue, and expiration time),
finally the signature section records the token signature.

A token is created and returned to the client whenever a registered
customer logs in (type &quot;credentials&quot;) or a guest customer requests it (type
&quot;guest&quot;). The token is returned in the response header as
Authorization: Bearer --token--

The client has to include the token in the request header as
Authorization: Bearer --token--
in any follow-up request. The server declines any follow-up requests
without a token or which cannot be verified based on the token signature
or expiration time. A token nearing its expiration time should be
exchanged for a new one (type &quot;refresh&quot;).

See &quot;API Usage &gt; JWT&quot; for more details on using JWT as an authentication
mechanism.
    */
    authorizeCustomer(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/customers/auth",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.clientId
        });
    }
    /**
    * Obtain the JSON Web Token (JWT) for registered customers whose credentials are stored using a third party system. Accepts loginId and clientId, returns a customer object in the response body and the JWT generated against the clientId in the response header.
    */
    authorizeTrustedSystem(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/customers/auth/trusted-system",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Reset customer password.
    */
    postResetPassword(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/customers/password/actions/reset",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Create reset password token.
    */
    postResetPasswordToken(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/customers/password/actions/create-reset-token",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Gets a customer.
    */
    getCustomer(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Updates a customer.
    */
    updateCustomer(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Returns a sorted pageable list of all customer addresses in the address book. The default page size is 10
customer addresses. The addresses are sorted so that the preferred address is always sorted first, with the remaining
addresses sorted alphabetically by ID.

When the customer cannot be found, NotFoundException
is thrown in a case of an agent, or an empty result list is returned in a case of JWT.
    */
    getCustomerAddresses(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/addresses",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Creates a new address with the given name for the given customer.
    */
    createCustomerAddress(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/addresses",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Retrieves a customer&#x27;s address by address name.
    */
    getCustomerAddress(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"],
            "addressName": parameters["addressName"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/addresses/{addressName}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Deletes a customer&#x27;s address by address name.
    */
    removeCustomerAddress(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"],
            "addressName": parameters["addressName"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/addresses/{addressName}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Updates a customer&#x27;s address by address name.
    */
    updateCustomerAddress(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"],
            "addressName": parameters["addressName"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/addresses/{addressName}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Gets the baskets of a customer.
    */
    getCustomerBaskets(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/baskets",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Returns a pageable list of all customer&#x27;s orders. The default page size is 10.
    */
    getCustomerOrders(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/orders",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Updates the customer&#x27;s password.
    */
    updateCustomerPassword(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/password",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Gets customer payment instruments for an customer. Can be limited to a specific payment
method by providing the query parameter paymentMethodId.

When the customer cannot be found NotFoundException
is thrown in a case of an agent, but an empty result list is returned in a case of JWT.
    */
    getCustomerPaymentInstruments(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/payment-instruments",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Adds a payment instrument to the customer information.
    */
    createCustomerPaymentInstrument(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/payment-instruments",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Deletes a customer&#x27;s payment instrument.
    */
    deleteCustomerPaymentInstrument(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"],
            "paymentInstrumentId": parameters["paymentInstrumentId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/payment-instruments/{paymentInstrumentId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Retrieves a customer&#x27;s payment instrument by its ID.
    */
    getCustomerPaymentInstrument(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"],
            "paymentInstrumentId": parameters["paymentInstrumentId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/payment-instruments/{paymentInstrumentId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Returns all customer product lists.
    */
    getCustomerProductLists(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/product-lists",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Creates a customer product list.
    */
    createCustomerProductList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/product-lists",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Deletes a customer product list.
    */
    deleteCustomerProductList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"],
            "listId": parameters["listId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/product-lists/{listId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Returns a customer product list of the given customer.
    */
    getCustomerProductList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"],
            "listId": parameters["listId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/product-lists/{listId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Changes a product list. Changeable properties are the name, description, and if the list is public.
    */
    updateCustomerProductList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"],
            "listId": parameters["listId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/product-lists/{listId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Returns a pageable list of all items of a customer&#x27;s product list. The default page size is 10.
    */
    getCustomerProductListItems(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"],
            "listId": parameters["listId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/product-lists/{listId}/items",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Adds an item to the customer&#x27;s product list. Considered values from the request body are:

type: A valid type, mandatory. This is the type of the item to be added to the customer&#x27;s product.
list.
priority: This is the priority of the item to be added to the customer&#x27;s product list.
public: This is the flag whether the item to be added to the customer&#x27;s product list is public.
product_id: A valid product ID, used for product item type only. This is the ID (SKU)
of the product related to the item to be added to the customer&#x27;s product list. It is mandatory for
product item type, and it must be a valid product id, otherwise
ProductListProductIdMissingException or ProductListProductNotFoundException
will be thrown.
quantity: Used for product item type only. This is the quantity of the item to be
added to the customer&#x27;s product list.
custom properties in the form c_&lt;CUSTOM_NAME&gt;: The custom property must correspond to a custom
attribute (&lt;CUSTOM_NAME&gt;) defined for ProductListItem. The value of this property must be valid for the
type of custom attribute defined for ProductListItem.
    */
    createCustomerProductListItem(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"],
            "listId": parameters["listId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/product-lists/{listId}/items",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Removes an item from a customer product list.
    */
    deleteCustomerProductListItem(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"],
            "listId": parameters["listId"],
            "itemId": parameters["itemId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/product-lists/{listId}/items/{itemId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Returns an item of a customer product list.
    */
    getCustomerProductListItem(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"],
            "listId": parameters["listId"],
            "itemId": parameters["itemId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/product-lists/{listId}/items/{itemId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Updates an item of a customer&#x27;s product list.
Considered values from the request body are:

priority: This is the priority of the customer&#x27;s product list item.
public: This is the flag whether the customer&#x27;s product list item is public.
quantity: This is the quantity of
the customer&#x27;s product list item. Used for product item type only.
custom properties in the form c_&lt;CUSTOM_NAME&gt;: The custom property
must correspond to a custom attribute (&lt;CUSTOM_NAME&gt;) defined for ProductListItem.
The value of this property must be valid for the type of custom attribute defined for ProductListItem.
    */
    updateCustomerProductListItem(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "customerId": parameters["customerId"],
            "listId": parameters["listId"],
            "itemId": parameters["itemId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/organizations/{organizationId}/customers/{customerId}/product-lists/{listId}/items/{itemId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Retrieves all public product lists as defined by the given search term (for example, email, first name, or last name).
    */
    getPublicProductListsBySearchTerm(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/product-lists",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Retrieves a public product list by ID.
    */
    getPublicProductList(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "listId": parameters["listId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/product-lists/{listId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Retrieves the items of a public product list.
    */
    getProductListItems(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "listId": parameters["listId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/product-lists/{listId}/items",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Retrieves an item from a public product list.
    */
    getProductListItem(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "listId": parameters["listId"],
            "itemId": parameters["itemId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/product-lists/{listId}/items/{itemId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=ShopperCustomers.js.map