"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
class Client extends core_1.BaseClient {
    constructor(config) {
        super(config);
        if (!!!config.baseUri) {
            this.clientConfig.baseUri = "https://{shortCode}.api.commercecloud.salesforce.com/pricing/assignments/{version}";
        }
    }
    /**
    * searches for promotion campaign assignments.

The promotioncampaignassignment search document contains a search object that allows filtering on various attributes.

The query attribute specifies a complex query that can be used to narrow down the search. attributes are grouped\n into different buckets.  these are the list of searchable attributes with their corresponding buckets:
  
   main:
     
          rank - integer
          startDate - date
          endDate - date
                    
          campaign:
            
            campaignId - string
            
          promotion:
              
            promotionId - string
            description - string
            enabled - boolean
            
          special handling:
            
          couponId - string
          
          
          only fields in the same bucket can be joined using a disjunction (or). for instance, when joining campaignId and rank above, only a conjunction is allowed (and), whereas promotionId                    and description can be joined to each other using an or because they are in the same bucket.  special handling fields must always use\n conjunctions. if the field is used in a      disjunction (or) that violates this rule, an exception will be thrown.
          
          expands that can be applied for the search request
          
          promotion
          campaign
         
         note that only searchable attributes (excluding the ones marked with above with an asterisk) can be used in sorting.
    */
    postSitesByIdPromotionCampaignAssignmentSearch(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/assignments",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=Assignments.js.map