import { BaseClient, BaseClientConfig } from "@commerce-apps/core";
import { CampaignSearchResult, Campaign } from "./Campaigns.types";
export { ErrorResponse, Offset, Limit, SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, CampaignSearchResult, Campaign, } from "./Campaigns.types";
declare type ClientConfig = BaseClientConfig & {
    baseUriParameters?: {
        "shortCode": string;
        "version": string;
    };
};
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Searches for campaigns using a search request object that allows filtering on various attributes.

  ## Supported Query Attributes

  The query attribute specifies a complex query that can be used to narrow down the search. A subset of these can optionally be used to sort the returned results.

  | Attribute | Type | Sortable |
  |-----------|--------|----------|
  | campaign_id | String | yes |
  | description | String | yes |
  | enabled | Boolean | yes |
  | coupon_id | String | no |
  | customer_group | String | no |
  | source_code | String | no |
  | start_date | Date | no |
  | end_date | Date | no |
  | last_modified | Date | no |

  These fields can only be used in queries as conjunctions (using &#x60;AND&#x60;). If the field is used in a disjunction (&#x60;OR&#x60;), an exception is thrown.

  ## Supported Expands

  This API does not support any expands.
    */
    campaignSearch(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CampaignSearchResult>;
    /**
    * Deletes the campaign by ID
    */
    deleteCampaignById(options?: {
        parameters?: {
            organizationId: any;
            campaignId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Action to get campaign information.
    */
    getCampaignById(options?: {
        parameters?: {
            organizationId: any;
            campaignId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Campaign>;
    /**
    * Updates the campaign with the specified information.
    */
    patchCampaignById(options: {
        parameters?: {
            organizationId: any;
            campaignId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Campaign>;
    /**
    * Creates a campaign using the information provided.
    */
    putCampaignById(options: {
        parameters?: {
            organizationId: any;
            campaignId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Campaign>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=Campaigns.d.ts.map