import { BaseClient, BaseClientConfig } from "@commerce-apps/core";
import { CouponRedemptionSearchResult, CouponCodes, CouponSearchResult, Coupon } from "./CouponManagementApi.types";
export { SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, ErrorResponse, Offset, Limit, CouponRedemptionSearchResult, CouponCodes, RedemptionLimits, CouponRedemption, RedemptionLimitPerPeriod, CouponCode, CouponSearchResult, Coupon, CouponMultiCodesRequest, CouponSystemCodeConfig, } from "./CouponManagementApi.types";
declare type ClientConfig = BaseClientConfig & {
    baseUriParameters?: {
        "shortCode": string;
        "version": string;
    };
};
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Searches for coupons.

 The Coupon Search document contains a search object that allows filtering on various attributes.

 The query attribute specifies a complex query that can be used to narrow down the search. These are the list
 of searchable attributes:
 
 coupon_id - String
 description - String
 type - one of {&quot;single_code&quot;, &quot;multiple_codes&quot;, &quot;system_codes&quot;}
 enabled - boolean
 

 Note that only searchable attributes can be used in sorting.

 The stats expand value is required to return the following fields in the Coupon document:
 
     exported_code_count
     redemption_count
     total_codes_count
 
    */
    postSitesByIdCouponSearch(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CouponSearchResult>;
    /**
    * Searches for coupon redemptions.

The Coupon Redemption Search document contains a search object that allows filtering on various attributes.


The query attribute specifies a complex query that can be used to narrow down the search. These are the list
of searchable attributes:

    code - String
    coupon_id - String
    customer_email - String
    order_no - String


Note that only searchable attributes can be used in sorting.

If the role to which the user belongs does not have View_Coupon_Codes permission, then the coupon codes returned will be masked.
    */
    postSitesByIDCouponRedemptionSearch(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | CouponRedemptionSearchResult>;
    /**
    * Delete a coupon by ID.
    */
    deleteCouponById(options?: {
        parameters?: {
            organizationId: any;
            couponId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Returns coupon information for the given coupon ID.

 The following fields are returned in the Coupon document when specifying the stats expand:

     exported_code_count
     redemption_count
     total_codes_count



 If the role to which the user belongs does not have the View_Coupon_Codes permission, then the coupon codes returned are masked.
    */
    getCouponById(options?: {
        parameters?: {
            organizationId: any;
            couponId: any;
            select?: any;
            expand?: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Coupon>;
    /**
    * Updates the coupon with the specified information.
    */
    patchCouponById(options: {
        parameters?: {
            organizationId: any;
            couponId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Coupon>;
    /**
    * Creates a coupon using the information provided. If a coupon exists with the same unique identifier,
 the coupon is replaced completely.
    */
    putCouponById(options: {
        parameters?: {
            organizationId: any;
            couponId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Coupon>;
    /**
    * Get the coupon codes for the given coupon.

 If the user role does not have the View_Coupon_Codes permission, then the coupon codes returned are masked.
    */
    getCodesByCouponId(options?: {
        parameters?: {
            organizationId: any;
            couponId: any;
            offset?: any;
            limit: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CouponCodes>;
    /**
    * Add or delete (modify) multiple codes to and from the supplied coupon.
    */
    postCodesByCouponId(options: {
        parameters?: {
            organizationId: any;
            couponId: any;
            delete?: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=CouponManagementApi.d.ts.map