"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
class Client extends core_1.BaseClient {
    constructor(config) {
        super(config);
        if (!!!config.baseUri) {
            this.clientConfig.baseUri = "https://{shortCode}.api.commercecloud.salesforce.com/pricing/coupons/{version}";
        }
    }
    /**
    * Searches for coupons.

 The Coupon Search document contains a search object that allows filtering on various attributes.

 The query attribute specifies a complex query that can be used to narrow down the search. These are the list
 of searchable attributes:
 
 coupon_id - String
 description - String
 type - one of {&quot;single_code&quot;, &quot;multiple_codes&quot;, &quot;system_codes&quot;}
 enabled - boolean
 

 Note that only searchable attributes can be used in sorting.

 The stats expand value is required to return the following fields in the Coupon document:
 
     exported_code_count
     redemption_count
     total_codes_count
 
    */
    postSitesByIdCouponSearch(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/coupons",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Searches for coupon redemptions.

The Coupon Redemption Search document contains a search object that allows filtering on various attributes.


The query attribute specifies a complex query that can be used to narrow down the search. These are the list
of searchable attributes:

    code - String
    coupon_id - String
    customer_email - String
    order_no - String


Note that only searchable attributes can be used in sorting.

If the role to which the user belongs does not have View_Coupon_Codes permission, then the coupon codes returned will be masked.
    */
    postSitesByIDCouponRedemptionSearch(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/coupons/redemptions",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Delete a coupon by ID.
    */
    deleteCouponById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "couponId": parameters["couponId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/organizations/{organizationId}/coupons/{couponId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
    /**
    * Returns coupon information for the given coupon ID.

 The following fields are returned in the Coupon document when specifying the stats expand:

     exported_code_count
     redemption_count
     total_codes_count



 If the role to which the user belongs does not have the View_Coupon_Codes permission, then the coupon codes returned are masked.
    */
    getCouponById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "couponId": parameters["couponId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/coupons/{couponId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
    /**
    * Updates the coupon with the specified information.
    */
    patchCouponById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "couponId": parameters["couponId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/organizations/{organizationId}/coupons/{couponId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Creates a coupon using the information provided. If a coupon exists with the same unique identifier,
 the coupon is replaced completely.
    */
    putCouponById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "couponId": parameters["couponId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/organizations/{organizationId}/coupons/{couponId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Get the coupon codes for the given coupon.

 If the user role does not have the View_Coupon_Codes permission, then the coupon codes returned are masked.
    */
    getCodesByCouponId(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "couponId": parameters["couponId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/coupons/{couponId}/codes",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
    /**
    * Add or delete (modify) multiple codes to and from the supplied coupon.
    */
    postCodesByCouponId(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "couponId": parameters["couponId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/coupons/{couponId}/codes",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=CouponManagementApi.js.map