import { BaseClient, BaseClientConfig } from "@commerce-apps/core";
import { GiftCertificate, GiftCertificateSearchResult } from "./GiftCertificates.types";
export { SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, ErrorResponse, Offset, Limit, Money, GiftCertificate, GiftCertificateSearchResult, AccountTransaction, GiftCertificates, } from "./GiftCertificates.types";
declare type ClientConfig = BaseClientConfig & {
    baseUriParameters?: {
        "shortCode": string;
        "version": string;
    };
};
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Creates a gift certificate using the information provided. If a gift certificate with
 the same unique identifier, it will be deleted and a new one will be created.
    */
    putGiftCertificateBySiteId(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | GiftCertificate>;
    /**
    * Searches for gift certificates. The query attribute specifies a complex query that can be used to narrow down the search. These are the list of searchable attributes:
 
 merchant_id - String
 masked_gift_certificate_code* - String
 order_no - String
 sender_name - String
 recipient_name - String
 recipient_email - String
 status - String
 enabled - Boolean
 message - String
 description - String
 creation_date - Date
 currency_mnemonic* - String
 
 * masked_gift_certificate_code, also known as just code, can only be used in a term query.  If a
 four-character code is supplied, it is assumed that the search is on the unmasked portion of the code, otherwise
 the full code must be matched.  Text queries are not allowed.
 * currency_mnemonic can only be joined with other attributes using a conjunction (AND).

 Note that only searchable attributes can be used in sorting.  The code attribute cannot be used for sorting.
    */
    postGiftCertificatesSearchBySiteId(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | GiftCertificateSearchResult>;
    /**
    * Deletes the gift certificate by merchant ID.
    */
    deleteGiftCertificateByIdBySiteId(options?: {
        parameters?: {
            organizationId: any;
            merchantId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | GiftCertificate>;
    /**
    * Action to get gift certificate information using merchant ID.
    */
    getGiftCertificateByIdBySiteId(options?: {
        parameters?: {
            organizationId: any;
            merchantId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | GiftCertificate>;
    /**
    * Updates the gift certificate with the specified information using merchant ID.
    */
    patchGiftCertificateByIdBySiteId(options: {
        parameters?: {
            organizationId: any;
            merchantId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | GiftCertificate>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=GiftCertificates.d.ts.map