import { BaseClient, BaseClientConfig } from "@commerce-apps/core";
import { PromotionSearchResult, Promotion } from "./Promotions.types";
export { ErrorResponse, Offset, Limit, SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, PromotionSearchResult, TimeOfDay, Campaign, PromotionCampaignAssignment, Tag, Promotion, PromotionAssignmentInformation, Schedule, Recurrence, PromotionAbtestGroupAssignment, } from "./Promotions.types";
declare type ClientConfig = BaseClientConfig & {
    baseUriParameters?: {
        "shortCode": string;
        "version": string;
    };
};
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Searches for promotions.
 
 The SearchRequest document contains a search object that allows filtering on various attributes.
 
 The query attribute specifies a complex query that can be used to narrow down the search. These are the searchable
 attributes:
 
 id - String
 name - String
 currency_code - String
 exclusivity - String
 enabled - Boolean
 
 Note that only searchable attributes can be used in sorting. Additionally, the following attribute can be used to
 sort:
 
 promotion_class - String
 
    */
    postPromotionSearch(options: {
        parameters?: {
            organizationId: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | PromotionSearchResult>;
    /**
    * Deletes the promotion by ID.
    */
    deletePromotionById(options?: {
        parameters?: {
            organizationId: any;
            id: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Action to get promotion information.
    */
    getPromotionById(options?: {
        parameters?: {
            organizationId: any;
            id: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Promotion>;
    /**
    * Updates the promotion with the specified information.
    */
    patchPromotionById(options: {
        parameters?: {
            organizationId: any;
            id: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Promotion>;
    /**
    * Creates a promotion using the information provided.
    */
    putPromotionById(options: {
        parameters?: {
            organizationId: any;
            id: any;
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Promotion>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=Promotions.d.ts.map