"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
class Client extends core_1.BaseClient {
    constructor(config) {
        super(config);
        if (!!!config.baseUri) {
            this.clientConfig.baseUri = "https://{shortCode}.api.commercecloud.salesforce.com/pricing/promotions/{version}";
        }
    }
    /**
    * Searches for promotions.
 
 The SearchRequest document contains a search object that allows filtering on various attributes.
 
 The query attribute specifies a complex query that can be used to narrow down the search. These are the searchable
 attributes:
 
 id - String
 name - String
 currency_code - String
 exclusivity - String
 enabled - Boolean
 
 Note that only searchable attributes can be used in sorting. Additionally, the following attribute can be used to
 sort:
 
 promotion_class - String
 
    */
    postPromotionSearch(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/promotions",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Deletes the promotion by ID.
    */
    deletePromotionById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "id": parameters["id"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/organizations/{organizationId}/promotions/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
    /**
    * Action to get promotion information.
    */
    getPromotionById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "id": parameters["id"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/promotions/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
    /**
    * Updates the promotion with the specified information.
    */
    patchPromotionById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "id": parameters["id"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/organizations/{organizationId}/promotions/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Creates a promotion using the information provided.
    */
    putPromotionById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "id": parameters["id"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/organizations/{organizationId}/promotions/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=Promotions.js.map