"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
class Client extends core_1.BaseClient {
    constructor(config) {
        super(config);
        if (!!!config.baseUri) {
            this.clientConfig.baseUri = "https://{shortCode}.api.commercecloud.salesforce.com/pricing/source-code-groups/{version}";
        }
    }
    /**
    * Deletes the source code group by ID.
    */
    deleteSourceCodeGroupsById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "id": parameters["id"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/organizations/{organizationId}/source-code-groups/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
    /**
    * Action to retrieve source code group information.
    */
    getSourceCodeGroupsById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "id": parameters["id"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/source-code-groups/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
    /**
    * Updates the source code group with the specified information.
    */
    patchSourceCodeGroupsById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "id": parameters["id"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/organizations/{organizationId}/source-code-groups/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Creates a source code group using the information provided.
    */
    putSourceCodeGroupsById(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "id": parameters["id"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/organizations/{organizationId}/source-code-groups/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Searches for source code groups.
 
 The query attribute specifies a complex query that can be used to narrow down the search. These are the list
 of searchable attributes:
 
 id - String
 description - String
 source_code* - String
 start_time - DateTime
 end_time - DateTime
 creation_date - DateTime
 enabled - Boolean
 active* - Boolean
 

 * - These fields can only be used in Queries as conjunctions (using AND).  If the field is used in a disjunction
 (OR) an exception will be thrown.
 
 The output of the query can also be sorted. These are the list of sortable attributes:
 
 id - String
 description - String
 enabled - Boolean
 creation_date - DateTime
 
 
 Expands that can be applied for the search request
 
 specifications - String
 
    */
    searchSourceCodeGroup(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/organizations/{organizationId}/source-code-groups",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=SourceCodeGroups.js.map