import { BaseClient, BaseClientConfig } from "@commerce-apps/core";
import { Variants, ProductOption, VariantSearchResult, VariationAttribute, Variant, VariationGroup, ProductOptionValue, VariationAttributes, ProductSearchResult, ProductOptions, Product, VariationAttributeValue, VariationGroups } from "./Products.types";
export { SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, Error, Money, Variants, ProductOption, Master, VariantSearchResult, VariationAttribute, CatalogCategoryId, ProductType, Variant, VariationGroup, ProductOptionValue, VariationAttributes, MarkupText, ImageGroup, MediaFile, VariationAttributeValues, ProductSearchResult, ProductOptions, Product, VariationAttributeValue, ProductOptionValues, VariationGroups, } from "./Products.types";
declare type ClientConfig = BaseClientConfig & {
    baseUriParameters?: {
        "shortCode": string;
    };
};
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Deletes the product by ID.
    */
    deleteProduct(options?: {
        parameters?: {
            organizationId: any;
            productId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Action to get product information.
    */
    getProduct(options?: {
        parameters?: {
            organizationId: any;
            productId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Product>;
    /**
    * Update a product using the information provided.

Fields that can be updated:
name, page_description, long_descripton, page_title,
page_keywords, brand, ean,upc, manufacture_sku,
manufacture_name, searchable, unit, searchable,
online_flag, default_variant_id.
    */
    updateProduct(options: {
        parameters?: {
            organizationId: any;
            productId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Product>;
    /**
    * Creates a product using the information provided. If a product with the same unique identifier exists, it will be cleaned and overwritten unless the header x-dw-validate-existing&#x3D;true is passed in with the request.
    */
    createProduct(options: {
        parameters?: {
            organizationId: any;
            productId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Product>;
    /**
    * Searches product variations for master product or variation group product.
 
 The query attribute specifies a complex query that can be used to narrow down the search. This is the list
 of searchable attributes:
 
 id - String
 product_id - String
 name - String
 online - SiteSpecific Boolean
 in_stock - Boolean
 searchable - SiteSpecific Boolean
 ats - Actual available quantity to sell - Double
 variation_attribute.ATTRIBUTE_ID (Ex:variation_attribute.color) - String
 
 Sortable Fields:
 
 id - String
 product_id - String
 name - String
 online - SiteSpecific Boolean
 in_stock - Boolean
 searchable - SiteSpecific Boolean
 ats - Actual available quantity to sell - Double
 

 Note:
 The calculated value of &quot;online&quot; and &quot;searchable&quot; is used in the search/sort.
 A search/sort by the the site specific attributes require the Site ID query parameter to be set.
 They are &quot;online&quot;, &quot;in_stock&quot;, &quot;searchable&quot; and &quot;ats&quot;.
  We assume that every field that starts with variation_attribute. is searchable and dot is followed by ATTRIBUTE_ID&quot;.


 The list of expansions to retrieve product information. The expand values available are:
          
            _base - Basic product information is retrieved. This expand is included by default.
            all - All product information including the following properties are retrieved:
            
                image
                price - siteId has to be provided to see this property
                price_currency - siteId has to be provided to see this property
            
            availability - Information related to the availability of the product variation.  This expand is not included by default.
            
                ats - siteId has to be provided to see this property
                in_stock - siteId has to be provided to see this property
                online - siteId has to be provided to see this property
                searchable
            
          variations - Information related to product variation is retrieved. This expand is included by default.
            attributes - Information related to product variation attributes is retrieved. This expand is not included by default.
          
    */
    searchProductVariations(options: {
        parameters?: {
            organizationId: any;
            productId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | VariantSearchResult>;
    /**
    * Reads variation groups for a product master.
    */
    getVariationGroupsForMasterProduct(options?: {
        parameters?: {
            organizationId: any;
            masterProductId: any;
            siteId?: any;
            offset?: any;
            limit: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | VariationGroups>;
    /**
    * Unassign a variation group product from a product master. The variation group product is not
  deleted: it remains as a normal product after unsassign.
    */
    deleteVariationGroupForMaster(options?: {
        parameters?: {
            organizationId: any;
            masterProductId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Read a variation group for a product master.
    */
    getVariationGroupForMasterProduct(options?: {
        parameters?: {
            organizationId: any;
            masterProductId: any;
            id: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | VariationGroup>;
    /**
    * Update a variation group for a product master.
    */
    updateVariationGroupInMasterProduct(options: {
        parameters?: {
            organizationId: any;
            masterProductId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | VariationGroup>;
    /**
    * Assign a variation group for a product master. If the variation group product does not initially exist,
  one is created using the body passed in.
    */
    assignVariationGroupForMasterProduct(options: {
        parameters?: {
            organizationId: any;
            masterProductId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | VariationGroup>;
    /**
    * Reads variation for a product master.
    */
    getVariationsForMasterProduct(options?: {
        parameters?: {
            organizationId: any;
            masterProductId: any;
            siteId?: any;
            offset?: any;
            limit: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Variants>;
    /**
    * Unassign a variation product from a product master.  The variation product is not deleted: it remains as a
  normal product after unsassign.
    */
    deleteVariationForMaster(options?: {
        parameters?: {
            organizationId: any;
            masterProductId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Read a variation for a product master.
    */
    getVariationForMasterProduct(options?: {
        parameters?: {
            organizationId: any;
            masterProductId: any;
            id: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Variant>;
    /**
    * Update a variation for a product master.
    */
    updateVariationsInMasterProduct(options: {
        parameters?: {
            organizationId: any;
            masterProductId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Variant>;
    /**
    * Assign a variation for a product master.  If the variation product does not initially exist,
  one is created using the body passed in.
    */
    createVariationForMasterProduct(options: {
        parameters?: {
            organizationId: any;
            masterProductId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Variant>;
    /**
    * Read local and shared product options of a product.
    */
    getProductOptions(options?: {
        parameters?: {
            organizationId: any;
            productId: any;
            currency?: any;
            offset?: any;
            limit: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | ProductOptions>;
    /**
    * Deletes a local product option or unbinds a shared product option from the product.
    */
    deleteProductOption(options?: {
        parameters?: {
            organizationId: any;
            productId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Read a local or shared product option of a product.
    */
    getProductOption(options?: {
        parameters?: {
            organizationId: any;
            productId: any;
            id: any;
            currency?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | ProductOption>;
    /**
    * Updates a local product option with the information provided.
    */
    updateProductOption(options: {
        parameters?: {
            organizationId: any;
            productId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ProductOption>;
    /**
    * Creates a local product option using the information provided or binds a shared product option to the product.
    */
    createProductOption(options: {
        parameters?: {
            organizationId: any;
            productId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ProductOption>;
    /**
    * Deletes a local product option value by ID.
    */
    deleteProductOptionValue(options?: {
        parameters?: {
            organizationId: any;
            id: any;
            optionId: any;
            productId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Read a local product option value of a local product option in a product.
    */
    getProductOptionValue(options?: {
        parameters?: {
            organizationId: any;
            id: any;
            optionId: any;
            productId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | ProductOptionValue>;
    /**
    * Updates a local product option value with the information provided.
    */
    updateProductOptionValue(options: {
        parameters?: {
            organizationId: any;
            id: any;
            optionId: any;
            productId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ProductOptionValue>;
    /**
    * Creates a local product option value using the information provided.
    */
    createProductOptionValue(options: {
        parameters?: {
            organizationId: any;
            id: any;
            optionId: any;
            productId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ProductOptionValue>;
    /**
    * Action to get product variation attribute value information.
    */
    getVariationAttributeValue(options?: {
        parameters?: {
            organizationId: any;
            productId: any;
            attributeId: any;
            id: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | VariationAttributeValue>;
    /**
    * Deletes the variation attribute value of a variation attribute bound to a master product.
    */
    deleteVariationAttributeValue(options?: {
        parameters?: {
            organizationId: any;
            productId: any;
            attributeId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Updates the variation attribute value of a variation attribute of a master product.
    */
    updateVariationAttributeValue(options: {
        parameters?: {
            organizationId: any;
            productId: any;
            attributeId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | VariationAttributeValue>;
    /**
    * Action to create a product variation attribute value.
    */
    createVariationAttributeValue(options: {
        parameters?: {
            organizationId: any;
            productId: any;
            attributeId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | VariationAttributeValue>;
    /**
    * Reads variation attributes of a product of type variant, variation master, or variation group.
    */
    getVariationAttributes(options?: {
        parameters?: {
            organizationId: any;
            productId: any;
            offset?: any;
            limit: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | VariationAttributes>;
    /**
    * Action to get variation attribute information only for master product.
    */
    getVariationAttribute(options?: {
        parameters?: {
            organizationId: any;
            productId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | VariationAttribute>;
    /**
    * Deletes the variation attribute by ID.
    */
    deleteVariationAttribute(options?: {
        parameters?: {
            organizationId: any;
            productId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Updates the variation attribute with the specified information.
  name
  slicing
  
    */
    updateVariationAttribute(options: {
        parameters?: {
            organizationId: any;
            productId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | VariationAttribute>;
    /**
    * Creates a variation attribute using the information provided.
    */
    createVariationAttribute(options: {
        parameters?: {
            organizationId: any;
            productId: any;
            id: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | VariationAttribute>;
    /**
    * &quot;Searches for products.\n\n The query attribute specifies a complex query that can be used to narrow down the search. Attributes are grouped\n into different buckets.  These are the list of searchable attributes with their corresponding buckets:\n\n Main:\n \n    id - String\n    name - String\n    online - SiteSpecific Boolean\n    searchable - SiteSpecific Boolean \n    valid_from - SiteSpefic DateTime \n    valid_to - SiteSpecfic DateTime \n    type - ProductType \n    creation_date - DateTime\n \n Catalog:\n \n    catalog_id - String\n \n Category:\n \n    category_id - String\n \n Special:\n \n    type - {\&quot;item\&quot;, \&quot;set, \&quot;bundle\&quot;, \&quot;master\&quot;, \&quot;part_of_product_set\&quot;, \&quot;bundled\&quot;, \&quot;variant\&quot;, \&quot;variation_group\&quot;, \&quot;option\&quot;, \&quot;retail_set\&quot;, \&quot;part_of_retail_set\&quot;}\n \n\n The sortable properties are:\n \n id - String\n name - String\n creation_date - DateTime\n \n\n Note that catalog_id is the id of the catalog to which products are assigned to.\n\n Only attributes in the same bucket can be joined using a disjunction (OR).\n For instance, when joining id and catalog_id above, only a conjunction is allowed (AND), whereas id\n and searchable can be joined using a disjunction because they are in the same bucket.  If an attribute\n is used in a disjunction (OR) that violates this rule, an exception will be thrown.\n\n The product search retrieves additional properties of the product when expansions are used.\n\tThe available expand attribute values are:\n \n        \t&#x27;all&#x27; will retrieve all the product properties.\n          &#x27;availability&#x27; will retrieve the following properties:\n            ats\n            in_stock\n            online\n\t\t    \n          &#x27;categories&#x27; will retrieve the following properties:\n            assigned_categories\n\t\t\t\n          &#x27;images&#x27; will retrieve the following properties:\n            image\n\t\t\t\n\t\t\t&#x27;all_images&#x27; used with images will retrieve the following properties:\n            image\n            image_groups\n\t\t\t\n          &#x27;prices&#x27; will retrieve the following properties:\n            price\n            price_currency\n\t\t\t\n          &#x27;sets&#x27; will retrieve the following properties:\n            set_products\n            product_sets\n\t\t\t\n          &#x27;bundles&#x27; will retrieve the following properties:\n            product_bundles\n            bundled_products\n            \n\t\t\t\n\n &quot;

    */
    searchProducts(options: {
        parameters?: {
            organizationId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ProductSearchResult>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=Products.d.ts.map