import { BaseClient, BaseClientConfig } from "@commerce-apps/core";
import { Category, CategoryResult, ProductResult, Product } from "./ShopperProducts.types";
export { SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, Error, OptionValue, Master, Category, CategoryResult, VariationAttribute, RecommendationType, ProductType, Recommendation, Variant, VariationGroup, ProductResult, ProductLink, Inventory, ImageGroup, Option, Product, Image, VariationAttributeValue, ProductPromotion, BundledProduct, } from "./ShopperProducts.types";
declare type ClientConfig = BaseClientConfig & {
    baseUriParameters?: {
        "shortCode": string;
    };
};
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Allows access to multiple products by a single request. This convenience resource should be used instead making separated requests, saving bandwidth and CPU time on the server. The URI is the same as requesting a single Product by ID, but multiple IDs wrapped by parentheses and separated are provided. If a parenthesis, or the separator, is part of the identifier itself, it has to be URL encoded. Instead of a single Product document, a result object of Product documents is returned. Note: Only products that are online and assigned to a site catalog are returned. The maximum number of IDs is 24. If none of the products requested are found, the cache-control header defaults to 60 seconds.
    */
    getProducts(options?: {
        parameters?: {
            organizationId: any;
            siteId: any;
            ids: any;
            expand?: any;
            inventoryIds?: any;
            currency?: any;
            locale?: any;
            allImages?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | ProductResult>;
    /**
    * To access a single products resource, you construct a URL with an ID (typically a SKU) for a product. In response, the server returns a corresponding product
document, provided the product is online and assigned to a site catalog. The document contains variation attributes
(including values) and the variant matrix. This data is provided for both the master and the variant.
    */
    getProduct(options?: {
        parameters?: {
            organizationId: any;
            id: any;
            siteId: any;
            expand?: any;
            inventoryIds?: any;
            currency?: any;
            locale?: any;
            allImages?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Product>;
    /**
    * When you use the URL template, the server returns multiple categories (a result object of category documents). You can use this template as a convenient way of obtaining multiple categories in a single request, instead of issuing separate requests for each category. You can specify up to 50 multiple IDs. You must enclose the list of IDs in parentheses. If a category identifier contains parenthesis or the separator sign, you must URL encode the character. The server only returns online categories.
    */
    getCategories(options?: {
        parameters?: {
            organizationId: any;
            siteId: any;
            ids: any;
            levels?: any;
            locale?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | CategoryResult>;
    /**
    * When you use the URL template below, the server returns a category identified by its ID; by default, the server
also returns the first level of subcategories, but you can specify another level by setting the levels
parameter. The server only returns online categories.
    */
    getCategory(options?: {
        parameters?: {
            organizationId: any;
            id: any;
            siteId: any;
            levels?: any;
            locale?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Category>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=ShopperProducts.d.ts.map