"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
class Client extends core_1.BaseClient {
    constructor(config) {
        super(config);
        if (!!!config.baseUri) {
            this.clientConfig.baseUri = "https://{shortCode}.api.commercecloud.salesforce.com/product/shopper-products/v1";
        }
        this.authSchemes["ShopperJWT"] = new core_1.AuthSchemes["ShopperJWT"]();
    }
    /**
    * Allows access to multiple products by a single request. This convenience resource should be used instead making separated requests, saving bandwidth and CPU time on the server. The URI is the same as requesting a single Product by ID, but multiple IDs wrapped by parentheses and separated are provided. If a parenthesis, or the separator, is part of the identifier itself, it has to be URL encoded. Instead of a single Product document, a result object of Product documents is returned. Note: Only products that are online and assigned to a site catalog are returned. The maximum number of IDs is 24. If none of the products requested are found, the cache-control header defaults to 60 seconds.
    */
    getProducts(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/products",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * To access a single products resource, you construct a URL with an ID (typically a SKU) for a product. In response, the server returns a corresponding product
document, provided the product is online and assigned to a site catalog. The document contains variation attributes
(including values) and the variant matrix. This data is provided for both the master and the variant.
    */
    getProduct(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "id": parameters["id"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/products/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * When you use the URL template, the server returns multiple categories (a result object of category documents). You can use this template as a convenient way of obtaining multiple categories in a single request, instead of issuing separate requests for each category. You can specify up to 50 multiple IDs. You must enclose the list of IDs in parentheses. If a category identifier contains parenthesis or the separator sign, you must URL encode the character. The server only returns online categories.
    */
    getCategories(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/categories",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * When you use the URL template below, the server returns a category identified by its ID; by default, the server
also returns the first level of subcategories, but you can specify another level by setting the levels
parameter. The server only returns online categories.
    */
    getCategory(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "id": parameters["id"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/categories/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=ShopperProducts.js.map