import { BaseClient, BaseClientConfig } from "@commerce-apps/core";
import { SortResponse, SearchSuggestionsResponse, RecommendersResponse, ActivityResponse, RecommendationsResponse, ActivityResponseBulk } from "./BetaFeatureEinsteinRecommendationsApi.types";
export { ClientIdParam, ViewSearchBulkActivityItems, CurrencyCodeParam, CookieIdParam, Error, ViewSearchSuggestionBulkActivityItems, SortResponse, AmountParam, ViewCategoryActivityData, ProductForView, ProductForCheckout, UserIdParam, ActvityRequestBatch, SiteIdParam, Recommender, ClientIpParam, SearchSuggestionsResponse, ViewSearchBulkActivity, RecommendersResponse, SortAttribute, ViewSearchSuggestionActivityData, ActivityResponse, ActivityResponseBatch, ViewCategoryBulkActivityItems, CategoryParam, ViewSearchActivityData, OrderIdParam, ViewSearchSuggestionBulkActivity, AutoSortActivityData, UuidParam, ViewCategoryBulkActivity, ClientUserAgentParam, RecommendationsResponse, AccountIdParam, ActivityResponseBulk, } from "./BetaFeatureEinsteinRecommendationsApi.types";
declare type ClientConfig = BaseClientConfig & {
    baseUriParameters?: {};
};
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Tells the Einstein engine when a user views a product.
    */
    sendViewProduct(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * Tells the Einstein engine when a user views a set of recommendations
    */
    sendViewReco(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * Tells the Einstein engine when a user clicks on a recommendation
    */
    sendClickReco(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * Tells the Einstein engine when a user views search results
    */
    sendViewSearch(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * Tells the Einstein engine when a user clicks on a search result.
    */
    sendClickSearch(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * This is the same as viewSearch, but for multiple activities across many sites
    */
    sendViewSearchBulk(options: {
        parameters?: {
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponseBulk>;
    /**
    * Tells the Einstein engine when a user views search suggestions
    */
    sendViewSearchSuggestion(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * This is the same as viewSearchSuggestion, but for multiple activities across many sites
    */
    sendViewSearchSuggestionBulk(options: {
        parameters?: {
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponseBulk>;
    /**
    * Tells the Einstein engine when a user views search results, with a psort score
    */
    sendViewSearchScore(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * This is the same as viewSearchScore, but for multiple activities across many sites
    */
    sendViewSearchScoreBulk(options: {
        parameters?: {
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponseBulk>;
    /**
    * Tells the Einstein engine when a user views a page that doesn&#x27;t fit another activity.
    */
    sendViewPage(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * Tells the Einstein engine when a user views a product
    */
    sendViewCategory(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * This is the same as viewCategory, but for multiple activities across many sites
    */
    sendViewCategoryBulk(options: {
        parameters?: {
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponseBulk>;
    /**
    * Tells the Einstein engine when a user views a category, with a psort score
    */
    sendViewCategoryScore(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * This is the same as viewCategoryScore, but for multiple activities across many sites
    */
    sendViewCategoryScoreBulk(options: {
        parameters?: {
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponseBulk>;
    /**
    * Tells the Einstein engine when a user begins to make a purchase, but has not completed it yet.
    */
    sendBeginCheckout(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * Tells the Einstein engine when a user adds an item to their cart.
    */
    sendAddToCart(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * Tells the Einstein engine when a user views their cart.
    */
    sendViewCart(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * Tells the Einstein engine when a user makes a purchase.

__NOTE__: If you are a Commerce Cloud customer and use the platform to process orders, then you do not need to implement this activity.
If you do implement this activity, you must authenticate via Account Manager (see Authentication section).

    */
    sendFinishCheckout(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * Tells the Einstein engine when a user creates an account.
    */
    sendCustomerSignup(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * Tells the Einstein engine about an email recipient.
    */
    sendEmailPixel(options?: {
        parameters?: {
            siteId: any;
            emailId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | ActivityResponse>;
    /**
    * Returns the UUID representing the user. Einsten will generate a new UUID for a new user.
    */
    getUUID(options?: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | ActivityResponse>;
    /**
    * Get a list of recommenders that can be used in recommendation requests.
    */
    getRecommenders(options?: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | RecommendersResponse>;
    /**
    * Get a set of recommendations
    */
    getRecommendations(options: {
        parameters?: {
            siteId: any;
            recommenderName: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | RecommendationsResponse>;
    /**
    * Get personalized sorting attributes
    */
    personalizedSort(options: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | SortResponse>;
    /**
    * Get suggestions for a given search text.
    */
    getSearchSuggestions(options?: {
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | SearchSuggestionsResponse>;
    /**
    * Redirect to a link, image, or caption for an email recommendation.
    */
    recommendationRedirect(options?: {
        parameters?: {
            siteId: any;
            recommenderName: any;
            linkType: any;
            rank: any;
            clientId: any;
            campaignId: any;
            emailId: any;
            anchor?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | void>;
    /**
    * Add new products to the Einstein catalog
    */
    addProducts(options: {
        parameters?: {};
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Accept or reject category recommendations
    */
    reviewRecommendations(options: {
        parameters?: {
            siteId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | void>;
    /**
    * Retrieve category recommendations from Einstein
    */
    getCategoryRecommendations(options?: {
        parameters?: {
            siteId: any;
            clientId: any;
            categoryId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Object>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=BetaFeatureEinsteinRecommendationsApi.d.ts.map