"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
class Client extends core_1.BaseClient {
    constructor(config) {
        super(config);
        if (!!!config.baseUri) {
            this.clientConfig.baseUri = "https://ai.salesforce.com/v3";
        }
    }
    /**
    * Tells the Einstein engine when a user views a product.
    */
    sendViewProduct(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/viewProduct",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine when a user views a set of recommendations
    */
    sendViewReco(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/viewReco",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine when a user clicks on a recommendation
    */
    sendClickReco(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/clickReco",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine when a user views search results
    */
    sendViewSearch(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/viewSearch",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine when a user clicks on a search result.
    */
    sendClickSearch(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/clickSearch",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * This is the same as viewSearch, but for multiple activities across many sites
    */
    sendViewSearchBulk(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {};
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/viewSearch/bulk",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine when a user views search suggestions
    */
    sendViewSearchSuggestion(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/viewSearchSuggestion",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * This is the same as viewSearchSuggestion, but for multiple activities across many sites
    */
    sendViewSearchSuggestionBulk(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {};
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/viewSearchSuggestion/bulk",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine when a user views search results, with a psort score
    */
    sendViewSearchScore(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/viewSearchScore",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * This is the same as viewSearchScore, but for multiple activities across many sites
    */
    sendViewSearchScoreBulk(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {};
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/viewSearchScore/bulk",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine when a user views a page that doesn&#x27;t fit another activity.
    */
    sendViewPage(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/viewPage",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine when a user views a product
    */
    sendViewCategory(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/viewCategory",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * This is the same as viewCategory, but for multiple activities across many sites
    */
    sendViewCategoryBulk(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {};
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/viewCategory/bulk",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine when a user views a category, with a psort score
    */
    sendViewCategoryScore(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/viewCategoryScore",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * This is the same as viewCategoryScore, but for multiple activities across many sites
    */
    sendViewCategoryScoreBulk(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {};
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/viewCategoryScore/bulk",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine when a user begins to make a purchase, but has not completed it yet.
    */
    sendBeginCheckout(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/beginCheckout",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine when a user adds an item to their cart.
    */
    sendAddToCart(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/addToCart",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine when a user views their cart.
    */
    sendViewCart(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/viewCart",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine when a user makes a purchase.

__NOTE__: If you are a Commerce Cloud customer and use the platform to process orders, then you do not need to implement this activity.
If you do implement this activity, you must authenticate via Account Manager (see Authentication section).

    */
    sendFinishCheckout(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/finishCheckout",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine when a user creates an account.
    */
    sendCustomerSignup(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/activities/{siteId}/customerSignup",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Tells the Einstein engine about an email recipient.
    */
    sendEmailPixel(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/activities/{siteId}/email",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
    /**
    * Returns the UUID representing the user. Einsten will generate a new UUID for a new user.
    */
    getUUID(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/activities/{siteId}/uuid",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
    /**
    * Get a list of recommenders that can be used in recommendation requests.
    */
    getRecommenders(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/personalization/recommenders/{siteId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
    /**
    * Get a set of recommendations
    */
    getRecommendations(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"],
            "recommenderName": parameters["recommenderName"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/personalization/recs/{siteId}/{recommenderName}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Get personalized sorting attributes
    */
    personalizedSort(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/personalization/sort/{siteId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Get suggestions for a given search text.
    */
    getSearchSuggestions(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/personalization/search/{siteId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
    /**
    * Redirect to a link, image, or caption for an email recommendation.
    */
    recommendationRedirect(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"],
            "recommenderName": parameters["recommenderName"],
            "linkType": parameters["linkType"],
            "rank": parameters["rank"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/personalization/email/{siteId}/{recommenderName}/{linkType}/{rank}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
    /**
    * Add new products to the Einstein catalog
    */
    addProducts(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {};
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/catalog/products",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Accept or reject category recommendations
    */
    reviewRecommendations(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/catalog/action/{siteId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers,
            body: (options || {}).body
        });
    }
    /**
    * Retrieve category recommendations from Einstein
    */
    getCategoryRecommendations(options) {
        const parameters = (options && options.parameters) ? options.parameters : {};
        const pathParameters = {
            "siteId": parameters["siteId"]
        };
        const queryParameters = lodash_1.default.omit(parameters, lodash_1.default.keys(pathParameters));
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/catalog/recs/{siteId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (options || {}).headers
        });
    }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=BetaFeatureEinsteinRecommendationsApi.js.map